@@ -18,7 +18,7 @@ use crate::{DiskUsage, Pid, ProcessExt, ProcessStatus, Signal};
 use crate::sys::process::ThreadStatus;
 use crate::sys::system::Wrap;
 
-/// Struct containing a process' information.
+#[doc = include_str!("../../../md_doc/process.md")]
 #[derive(Clone)]
 pub struct Process {
     pub(crate) name: String,
@@ -603,6 +603,7 @@ fn update_proc_disk_activity(p: &mut Process) {
     }
 }
 
+#[allow(clippy::uninit_vec)]
 pub(crate) fn get_proc_list() -> Option<Vec<Pid>> {
     let count = unsafe { libc::proc_listallpids(::std::ptr::null_mut(), 0) };
     if count < 1 {
