@@ -4,8 +4,9 @@
 // Copyright (c) 2015 Guillaume Gomez
 //
 
-use crate::{DiskUsage, Pid, ProcessExt, Signal};
+use crate::{DiskUsage, Pid, ProcessExt, ProcessStatus, Signal};
 
+use std::fmt;
 use std::path::Path;
 
 impl fmt::Display for ProcessStatus {
@@ -39,7 +40,7 @@ impl ProcessExt for Process {
     }
 
     fn exe(&self) -> &Path {
-        &Path::new("")
+        Path::new("")
     }
 
     fn pid(&self) -> Pid {
@@ -51,11 +52,11 @@ impl ProcessExt for Process {
     }
 
     fn cwd(&self) -> &Path {
-        &Path::new("")
+        Path::new("")
     }
 
     fn root(&self) -> &Path {
-        &Path::new("")
+        Path::new("")
     }
 
     fn memory(&self) -> u64 {
