@@ -4,10 +4,10 @@
 // Copyright (c) 2018 Guillaume Gomez
 //
 
-use crate::{DiskUsage, Pid, ProcessExt, Signal};
+use crate::{DiskUsage, Pid, ProcessExt, ProcessStatus, Signal};
 
 use std::ffi::OsString;
-use std::fmt::{self, Debug};
+use std::fmt;
 use std::mem::{size_of, zeroed, MaybeUninit};
 use std::ops::Deref;
 use std::os::windows::ffi::OsStringExt;
@@ -48,25 +48,12 @@ use winapi::um::winnt::{
     RTL_OSVERSIONINFOEXW, ULARGE_INTEGER,
 };
 
-/// Enum describing the different status of a process.
-#[derive(Clone, Copy, Debug)]
-pub enum ProcessStatus {
-    /// Currently runnable.
-    Run,
-}
-
-impl ProcessStatus {
-    /// Used to display `ProcessStatus`.
-    pub fn as_str(&self) -> &str {
-        match *self {
-            ProcessStatus::Run => "Runnable",
-        }
-    }
-}
-
 impl fmt::Display for ProcessStatus {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        f.write_str(self.as_str())
+        f.write_str(match *self {
+            ProcessStatus::Run => "Runnable",
+            _ => "Unknown",
+        })
     }
 }
 
@@ -94,10 +81,11 @@ impl<T: Clone> Deref for PtrWrapper<T> {
     }
 }
 
+#[allow(clippy::non_send_fields_in_send_ty)]
 unsafe impl<T: Clone> Send for PtrWrapper<T> {}
 unsafe impl<T: Clone> Sync for PtrWrapper<T> {}
 
-/// Struct containing a process' information.
+#[doc = include_str!("../../md_doc/process.md")]
 pub struct Process {
     name: String,
     cmd: Vec<String>,
@@ -462,6 +450,7 @@ unsafe fn get_start_time(handle: HANDLE) -> u64 {
     tmp / 10_000_000 - 11_644_473_600
 }
 
+#[allow(clippy::uninit_vec)]
 unsafe fn ph_query_process_variable_size(
     process_handle: HANDLE,
     process_information_class: PROCESSINFOCLASS,
@@ -539,6 +528,7 @@ unsafe fn get_region_size(handle: HANDLE, ptr: LPVOID) -> Result<usize, &'static
     Ok((meminfo.RegionSize as isize - ptr.offset_from(meminfo.BaseAddress)) as usize)
 }
 
+#[allow(clippy::uninit_vec)]
 unsafe fn get_process_data(
     handle: HANDLE,
     ptr: LPVOID,
