@@ -88,6 +88,7 @@ unsafe fn init_load_avg() -> Mutex<Option<LoadAvg>> {
     let mut query = null_mut();
 
     if PdhOpenQueryA(null_mut(), 0, &mut query) != ERROR_SUCCESS as _ {
+        sysinfo_debug!("init_load_avg: PdhOpenQueryA failed");
         return Mutex::new(None);
     }
 
@@ -100,17 +101,20 @@ unsafe fn init_load_avg() -> Mutex<Option<LoadAvg>> {
     ) != ERROR_SUCCESS as _
     {
         PdhCloseQuery(query);
+        sysinfo_debug!("init_load_avg: failed to get processor queue length");
         return Mutex::new(None);
     }
 
     let event = CreateEventA(null_mut(), FALSE, FALSE, b"LoadUpdateEvent\0".as_ptr() as _);
     if event.is_null() {
         PdhCloseQuery(query);
+        sysinfo_debug!("init_load_avg: failed to create event `LoadUpdateEvent`");
         return Mutex::new(None);
     }
 
     if PdhCollectQueryDataEx(query, SAMPLING_INTERVAL as _, event) != ERROR_SUCCESS as _ {
         PdhCloseQuery(query);
+        sysinfo_debug!("init_load_avg: PdhCollectQueryDataEx failed");
         return Mutex::new(None);
     }
 
@@ -126,6 +130,7 @@ unsafe fn init_load_avg() -> Mutex<Option<LoadAvg>> {
     {
         PdhRemoveCounter(counter);
         PdhCloseQuery(query);
+        sysinfo_debug!("init_load_avg: RegisterWaitForSingleObject failed");
         Mutex::new(None)
     } else {
         Mutex::new(Some(LoadAvg::default()))
@@ -175,6 +180,7 @@ impl Query {
                 };
                 Some(Query { internal: q })
             } else {
+                sysinfo_debug!("Query::new: PdhOpenQueryA failed");
                 None
             }
         }
@@ -198,6 +204,7 @@ impl Query {
                     let data = *display_value.u.doubleValue();
                     Some(data as f32)
                 } else {
+                    sysinfo_debug!("Query::get: PdhGetFormattedCounterValue failed");
                     Some(0.)
                 };
             }
@@ -208,6 +215,7 @@ impl Query {
     #[allow(clippy::ptr_arg)]
     pub fn add_counter(&mut self, name: &String, getter: Vec<u16>) -> bool {
         if self.internal.data.contains_key(name) {
+            sysinfo_debug!("Query::add_english_counter: doesn't have key `{:?}`", name);
             return false;
         }
         unsafe {
@@ -216,7 +224,11 @@ impl Query {
             if ret == ERROR_SUCCESS as _ {
                 self.internal.data.insert(name.clone(), counter);
             } else {
-                sysinfo_debug!("failed to add counter '{}': {:x}...", name, ret);
+                sysinfo_debug!(
+                    "Query::add_english_counter: failed to add counter '{}': {:x}...",
+                    name,
+                    ret,
+                );
                 return false;
             }
         }
@@ -416,6 +428,7 @@ pub fn get_frequencies(nb_processors: usize) -> Vec<u64> {
             .map(|i| i.CurrentMhz as u64)
             .collect::<Vec<_>>()
     } else {
+        sysinfo_debug!("get_frequencies: CallNtPowerInformation failed");
         vec![0; nb_processors]
     }
 }
@@ -445,7 +458,12 @@ pub fn get_physical_core_count() -> Option<usize> {
             // For some reasons, the function might return a size not big enough...
             match e.raw_os_error() {
                 Some(value) if value == ERROR_INSUFFICIENT_BUFFER as _ => {}
-                _ => return None,
+                _ => {
+                    sysinfo_debug!(
+                        "get_physical_core_count: GetLogicalProcessorInformationEx failed"
+                    );
+                    return None;
+                }
             }
         } else {
             break;
